=======================================
Using eBooks with Runestone Academy
=======================================

If you are an instructor wanting to learn more about how to use the `Runestone Academy <https://runestone.academy>`_ website, then this is the resource for you.
The Runestone platform allows you to create, modify, use, and serve interactive ebooks. This instructors guide was built  using the Runestone platform.

With Runestone you can:

* Use any of the existing ebooks that are listed at the following link `here <http://runestoneinteractive.org/library.html>`_.
* Create a private course for your students as shown in the following Video and Chapter 4 of this guide.  Your course will have to have a unique name and your students can register for the course using the unique name.

Quick Start
===========

.. youtube:: IGg_SUWEnGU
    :divid: gettingstarted
    :height: 315
    :width: 560
    :align: left


Table of Contents
=================

.. toctree::
   :numbered:
   :maxdepth: 2

   Registration/registerYourself.rst
   CustomCourses/toctree.rst
   Registration/toctree.rst
   InstructorInterface/toctree.rst
   WritingExercises/toctree.rst   
   ActiveCode/toctree.rst
   Assessments/toctree.rst
   Visualizers/toctree.rst
   Containers/toctree.rst
   Video/toctree.rst
   Misc/toctree.rst


What's Next?
::::::::::::

No matter what your use case for Runestone textbooks, we encourage you to become a part of our community.  There are many ways you can get involved.

* Join the discussion on our `Google Group <https://groups.google.com/forum/#!forum/runestone_instructors>`_
* Add some exercises to the Exercise Bank!
* Report any bugs you find on `Github <https://github.com/RunestoneInteractive/RunestoneComponents>`_.
* If you have an idea for a lab, lesson, chapter, or book you would like to make available for others write it up and send it to us.
* If you are a Javascript coder, we have lots of feature ideas and bugs to squash in the existing system.
* If you are a backend programmer, help us squash bugs there too.
* If you are a designer, and would like to improve the look and feel of the books, we would welcome suggestions and CSS!


Additional Useful Links
:::::::::::::::::::::::

Runestone uses the ``restructuredText`` (rst) markup language.  We chose this over markdown largely because rst is extensible.  Nearly all of the basic markup tasks are already handled by restructuredText.  You should check out the docs for the basics of restructuredText (link below). Our extensions are all for the interactive elements.  One key hint about restructuredText:  Its like **Python** -- *indentation matters!*

* `restructuredText Docs <http://docutils.sourceforge.net/rst.html>`_
* `Runestone Docs <http://runestoneinteractive.org/build/html/index.html>`_

